# PyGrabIt


## Main Script

In order to run the main script, follow these instructions: 

1) Select a directory to save this repository to. This can be done by creating a directory on your Desktop (for example: C:/MyPC/Desktop/GitRepo/).
Open the Git bash and type:
```
cd "C:/MyPC/Desktop/GitRepo/"
```

2) Download (clone) this repository in the directory that we previously created. This can be done by opening Git bash inside the directory we just created (for example: C:/MyPC/Desktop/GitRepo/) and typing:
```
git clone "https://github.com/ludvikalkhoury/PyGrabIt.git"
```
and then go the repository directory by typing:
```
cd PyGrabIt/
```

3) Now that you have the repository, run setup.py to install all dependent packages:
```
python -m pip install -e  .
```

4) You can compute PyGrabIt, using this command:
```
python -m PyGrabIt
```

Here is an example:
![image](https://github.com/user-attachments/assets/7aab823d-8005-4b7c-8155-90cc59a3b7f6)

